@@ -1,5 +1,5 @@
 /* scram.c --- Test the SCRAM mechanism.
- * Copyright (C) 2009  Simon Josefsson
+ * Copyright (C) 2009, 2010  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -26,6 +26,7 @@
 #include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
+#include <stdbool.h>
 
 #include "utils.h"
 
@@ -142,6 +143,8 @@ doit (void)
 
   for (i = 0; i <= 15; i++)
     {
+      bool server_first = (i % 2) == 0;
+
       if (debug)
 	printf ("Iteration %d ...\n", i);
 
@@ -158,9 +161,31 @@ doit (void)
 	  return;
 	}
 
+      if (server_first)
+	{
+	  res = gsasl_step (server, NULL, 0, &s1, &s1len);
+	  if (res != GSASL_NEEDS_MORE)
+	    {
+	      fail ("gsasl_step[%d](0) failed (%d):\n%s\n", i, res,
+		    gsasl_strerror (res));
+	      return;
+	    }
+
+	  if (s1len != 0)
+	    fail ("dummy initial server step produced output?!\n");
+
+	  if (debug)
+	    printf ("S: %.*s [%c]\n", s1len, s1, res == GSASL_OK ? 'O' : 'N');
+	}
+      else
+	{
+	  s1 = NULL;
+	  s1len = 0;
+	}
+
       /* Client first... */
 
-      res = gsasl_step (client, NULL, 0, &s1, &s1len);
+      res = gsasl_step (client, s1, s1len, &s1, &s1len);
       if (res != GSASL_NEEDS_MORE)
 	{
 	  fail ("gsasl_step[%d](1) failed (%d):\n%s\n", i, res,
@@ -169,7 +194,7 @@ doit (void)
 	}
 
       if (debug)
-	printf ("C: %.*s\n", s1len, s1);
+	printf ("C: %.*s [%c]\n", s1len, s1, res == GSASL_OK ? 'O' : 'N');
 
       /* Server first... */
 
@@ -183,7 +208,7 @@ doit (void)
 	}
 
       if (debug)
-	printf ("S: %.*s\n", s2len, s2);
+	printf ("S: %.*s [%c]\n", s2len, s2, res == GSASL_OK ? 'O' : 'N');
 
       /* Client final... */
 
@@ -197,7 +222,7 @@ doit (void)
 	}
 
       if (debug)
-	printf ("C: %.*s\n", s1len, s1);
+	printf ("C: %.*s [%c]\n", s1len, s1, res == GSASL_OK ? 'O' : 'N');
 
       /* Server final... */
 
@@ -211,7 +236,7 @@ doit (void)
 	}
 
       if (debug)
-	printf ("S: %.*s\n", s2len, s2);
+	printf ("S: %.*s [%c]\n", s2len, s2, res == GSASL_OK ? 'O' : 'N');
 
       /* Let client parse server final... */
 
@@ -224,8 +249,8 @@ doit (void)
 	  return;
 	}
 
-      if (debug)
-	printf ("C: %.*s\n", s1len, s1);
+      if (s1len != 0)
+	fail ("dummy final client step produced output?!\n");
 
       {
 	const char *p = gsasl_property_fast (server, GSASL_AUTHID);
